@@ -15,5 +15,5 @@ class CSVWriter(PolarsStep):
     async def process(self, ctx: SpinePolarsContext, df: PolarsDataFrame = None) -> PolarsDataFrame:
         ctx.logger.info(f"Writing CSV to {self.path} with headers={self.headers}")
         writer = df.collect().write_csv if ctx.lazy else df.write_csv
-        writer(self.path, has_header=self.headers, batch_size=self.batch_size, sep=self.sep)
+        writer(self.path, has_header=self.headers, batch_size=self.batch_size, separator=self.sep)
         return df
